/*
Copyright (c) 2019 SparkFun Electronics

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/
#ifndef MBED_PINNAMES_H
#define MBED_PINNAMES_H

#include "am_bsp.h"
#include "objects_gpio.h"

#ifdef __cplusplus
extern "C"
{
#endif

#define NC_VAL (int)0xFFFFFFFF

typedef enum
{
    // Digital naming
    D0 = AM_BSP_GPIO_IOS_SCL,              // ACCELL_INT2/2
    D1 = AM_BSP_GPIO_MSPI_D5,              // GPIO 1
    D3 = 3,                                // GPIO 3
    D4 = AM_BSP_GPIO_CAMERA_HM01B0_INT,    // GPIO4/CAMERA_Y4  / 2
    D5 = AM_BSP_GPIO_CAMERA_HM01B0_D5,     // GPIO5/CAMERA_Y3  / 2
    D6 = AM_BSP_GPIO_CAMERA_HM01B0_D6,     // GPIO6/CAMERA_Y0  / 2
    D7 = AM_BSP_GPIO_CAMERA_HM01B0_D7,     // GPIO7/CAMERA_XCLK  / 2
    D8 = AM_BSP_GPIO_IOM1_SCL,             // GPIO8/CAMERA_Y1  / 2
    D9 = AM_BSP_GPIO_IOM1_SDA,             // GPIO9/CAMERA_Y1  / 2
    D10 = AM_BSP_GPIO_CAMERA_HM01B0_DVDDEN,// GPIO10/CAMERA_DVDD_EN /2
    D11 = AM_BSP_GPIO_MIC0,                // GPIO11/MICO /2
    D12 = AM_BSP_GPIO_CAMERA_HM01B0_TRIG,  // GPIO12/CAMERA_VSYNC /2
    D13 = AM_BSP_GPIO_IOM4_CS,             // GPIO13/CAMERA_PWON  /2
    D14 = AM_BSP_GPIO_BUTTON14,            // GPIO14/USER_BUTTON
    D15 = AM_BSP_GPIO_CAMERA_HM01B0_VSYNC, // GPIO15/CAMERA/RESET /2
    D17 = 17,                              // GPIO17/ACCEL_INT1/2
    D20 = AM_BSP_GPIO_SWDCK,               // GPIO20/SWDCK
    D21 = AM_BSP_GPIO_SWDIO,               // GPIO21/SWDIO
    D22 = AM_BSP_GPIO_CAMERA_HM01B0_HSYNC, // GPIO22/CAMERA_Y5/2
    D23 = AM_BSP_GPIO_CAMERA_HM01B0_PCLK,  // GPIO23/CAMERA_PCLK/2
    D24 = AM_BSP_GPIO_CAMERA_HM01B0_D0,    // GPIO24/CAMERA_Y6/2
    D25 = AM_BSP_GPIO_CAMERA_HM01B0_D1,    // GPIO25/I2C_SDA_CAMERA/2
    D26 = AM_BSP_GPIO_CAMERA_HM01B0_D2,    // GPIO26/CAMERA_HREF/2
    D27 = AM_BSP_GPIO_CAMERA_HM01B0_D3,    // GPIO27/I2C_SCL_CAMERA/2
    D28 = AM_BSP_GPIO_CAMERA_HM01B0_D4,    // GPIO28/CAMERA_Y7/2
    D29 = AM_BSP_GPIO_MIC1,                // GPIO29/MIC1/2
    D33 = AM_BSP_GPIO_ITM_SWO,             // GPIO33/SWO
    D36 = 36,                              // GPIO36_J3_4
    D37 = AM_BSP_GPIO_LED_BLUE,            // GPIO37_LED_BLUE
    D38 = AM_BSP_GPIO_IOM3_MOSI,           // GPIO38_J3_32
    D39 = AM_BSP_GPIO_IOM4_SCL,            // GPIO39_QWICC_SCL
    D40 = AM_BSP_GPIO_IOM4_SDA,            // GPIO40_QWICC_SDA
    D42 = AM_BSP_GPIO_IOM3_SCL,            // GPIO42/I2C_SCLK/2
    D43 = AM_BSP_GPIO_IOM3_SDA,            // GPIO43/I2C_SDA/2
    D44 = AM_BSP_GPIO_LED_GREEN,           // GPIO44/LED_GREEN
    D46 = AM_BSP_GPIO_LED_RED,             // GPIO46/ LED_RED
    D47 = AM_BSP_GPIO_LED_YELLOW,          // GPIO47/ LED_YELLOW

    // // Analog naming
    // No analog pins

    // mbed buttons
    BUTTON1 = AM_BSP_GPIO_BUTTON0,

    // LEDs
    LED_RED = AM_BSP_GPIO_LED_RED,
    LED_BLUE = AM_BSP_GPIO_LED_BLUE,
    LED_GREEN = AM_BSP_GPIO_LED_GREEN,
    LED_YELLOW = AM_BSP_GPIO_LED_YELLOW,

    // mbed original LED naming
    LED1 = AM_BSP_GPIO_LED0,
    LED2 = AM_BSP_GPIO_LED1,
    LED3 = AM_BSP_GPIO_LED2,
    LED4 = AM_BSP_GPIO_LED3,

    // I2C
    I2C_SCL = AM_BSP_QWIIC_I2C_SCL_PIN,
    I2C_SDA = AM_BSP_QWIIC_I2C_SDA_PIN,

    // Qwiic
    QWIIC_SCL = I2C_SCL,
    QWIIC_SDA = I2C_SDA,

    // SPI
    // The SFE_EDGE does not expose a complete IOM peripheral for SPI

    // UART
    SERIAL_TX = AM_BSP_PRIM_UART_TX_PIN,
    SERIAL_RX = AM_BSP_PRIM_UART_RX_PIN,
    USBTX = SERIAL_TX,
    USBRX = SERIAL_RX,

    // Not connected
    NC = NC_VAL
} PinName;

#define STDIO_UART_TX USBTX
#define STDIO_UART_RX USBRX

#ifdef __cplusplus
}
#endif

#endif
